---
title: <span class="badge builder"></span> ElasticsearchTermsSettings
---
# <span class="badge builder"></span> ElasticsearchTermsSettings

## Constructor

```python
ElasticsearchTermsSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.ElasticsearchTermsSettings
```

### <span class="badge object-method"></span> min_doc_count

```python
def min_doc_count(min_doc_count: str) -> typing.Self
```

### <span class="badge object-method"></span> missing

```python
def missing(missing: str) -> typing.Self
```

### <span class="badge object-method"></span> order

```python
def order(order: elasticsearch.TermsOrder) -> typing.Self
```

### <span class="badge object-method"></span> order_by

```python
def order_by(order_by: str) -> typing.Self
```

### <span class="badge object-method"></span> size

```python
def size(size: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ElasticsearchTermsSettings](./object-ElasticsearchTermsSettings.md)
